@@ -1,3 +1,4 @@
+import copy
 import os
 import time
 import datetime
@@ -249,7 +250,9 @@ class DataSource:
                       environment="production",
                       period=None,
                       reference_date=None,
-                      query_params_from_function={}):
+                      query_params_from_function=None):
+        if query_params_from_function is None:
+            query_params_from_function = dict()
         if query_config.get("template"):
             query_template_file_name = query_config.get("template")
         else:
@@ -321,13 +324,14 @@ class DataSource:
                 return_result=False,
                 period=None,
                 reference_date=None,
-                query_params={}):
+                query_params=None):
+        if not query_params:
+            query_params = dict()
         query_list, queries_config, schema_name, folder_path = self._get_query_list(
             layer_name=layer_name,
             query_name=query_name
         )
-        result_dict = {}
-        result_dict[layer_name] = {}
+        result_dict = {layer_name: {}}
         for query in query_list:
             result_dict[layer_name][query] = {}
             result_dict[layer_name][query]["started_at"] = str(datetime.datetime.now())
@@ -338,6 +342,7 @@ class DataSource:
                 schema_name_filled_query = schema_name if environment == 'production' else (
                         schema_name + "_" + environment
                 )
+            query_params_copy = copy.deepcopy(query_params)
             filled_query = self._filled_query(
                 query_config=query_config,
                 query=query,
@@ -347,7 +352,7 @@ class DataSource:
                 environment=environment,
                 period=period,
                 reference_date=reference_date,
-                query_params_from_function=query_params
+                query_params_from_function=query_params_copy
             )
             destination_tables_with_schema = get_destination_tables_with_schema(
                 schema_name=schema_name,
@@ -356,7 +361,13 @@ class DataSource:
                 environment=environment
             )
             if environment != "production":
-                log_info(filled_query)
+                file_name = "./tmp/%s/%s.sql" % (layer_name, query)
+                os.makedirs(os.path.dirname(file_name), exist_ok=True)
+                f = open(file_name, "w")
+                f.write(filled_query)
+                f.close()
+                path = os.path.abspath(file_name)
+                log_info("file://%s" % path)
             try:
                 query_result = self.dbstream.execute_query(filled_query, apply_special_env=False)
             except Exception as e:
